@@ -15,6 +15,7 @@ CallerXDaemon::CallerXDaemon(QObject *parent) :
     settings.setValue("whitelistmode", whitelistmode);
     settings.setValue("whitelistpath", whitelistpath);
     settings.setValue("blacklistpath", blacklistpath);
+    activetimer = false;
 }
 
 CallerXDaemon::~CallerXDaemon()
@@ -23,8 +24,12 @@ CallerXDaemon::~CallerXDaemon()
     delete fileWatcher;
     settings.sync();
 }
-
 void CallerXDaemon::Start()
+{
+    QTimer::singleShot(2000, this, SLOT(initialize()));
+}
+
+void CallerXDaemon::initialize()
 {
     if (!QDBusConnection::systemBus().connect(BUS_NAME, BUS_PATH, BUS_NAME, "Coming", this, SLOT(callScreen(const QDBusObjectPath&, const QString&)))){
         emit quit();
@@ -54,7 +59,7 @@ void CallerXDaemon::Start()
 
     fileWatcher = new QFileSystemWatcher();
     fileWatcher->addPath(listPath);
-    QObject::connect(fileWatcher, SIGNAL(fileChanged(const QString&)), this, SLOT(loadlist()));
+    QObject::connect(fileWatcher, SIGNAL(fileChanged(const QString&)), this, SLOT(updatelist()));
 
     if (whitelistmode) {
         loadwhitelist();
@@ -155,6 +160,7 @@ void CallerXDaemon::loadlist()
             line = in.readLine();
         }
         blocklist.close();
+        activetimer = false;
     }
 }
 
@@ -170,3 +176,12 @@ void CallerXDaemon::addtolist(const QString &number)
         blocklist.close();
     }
 }
+
+void CallerXDaemon::updatelist()
+{
+    if (!activetimer) {
+        activetimer = true;
+        QTimer::singleShot(1000, this, SLOT(loadlist()));
+    }
+
+}
