@@ -11,6 +11,7 @@
 #include <QList>
 #include <QString>
 #include <QTextStream>
+#include <QTimer>
 
 #define BUS_NAME "com.nokia.csd.Call"
 #define BUS_PATH "/com/nokia/csd/call"
@@ -41,9 +42,11 @@ public slots:
     Q_SCRIPTABLE void addrecentnumber();
 
 private slots:
+    void initialize();
     void callScreen(const QDBusObjectPath&, const QString&);
     void callRelease(const QString&);
     void loadlist();
+    void updatelist();
     void setloadlist(const QString&, bool m);
     void addtolist(const QString&);
     bool isBlocked(const QString&);
@@ -52,7 +55,7 @@ private:
     QFileSystemWatcher* fileWatcher;
     QList<QString> nlist;
     QString listPath, whitelistpath, blacklistpath, n, callPath;
-    bool whitelistmode;
+    bool whitelistmode, activetimer;
     QSettings settings;
 };
 #endif // DAEMON_H
